@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -14,8 +14,8 @@
 
 #include <AkonadiCore/Collection>
 #include <AkonadiCore/Item>
-#include <KCalendarCore/Journal>
 #include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
 #include <KCalendarCore/Todo>
 
 class CalendarIndexer : public AbstractIndexer
@@ -26,7 +26,7 @@ public:
      * should be stored
      */
     explicit CalendarIndexer(const QString &path);
-    ~CalendarIndexer();
+    ~CalendarIndexer() override;
 
     QStringList mimeTypes() const override;
 
@@ -36,6 +36,7 @@ public:
     void remove(const Akonadi::Item &item) override;
     void remove(const Akonadi::Collection &collection) override;
     void move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from, Akonadi::Collection::Id to) override;
+
 private:
     void indexEventItem(const Akonadi::Item &item, const KCalendarCore::Event::Ptr &event);
     void indexJournalItem(const Akonadi::Item &item, const KCalendarCore::Journal::Ptr &journal);
