@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -8,13 +8,13 @@
 
 #include <xapian.h>
 
-#include "indexeditems.h"
 #include "akonadi_search_pim_debug.h"
+#include "indexeditems.h"
 
-#include <QStandardPaths>
-#include <QHash>
-#include <QDir>
 #include <AkonadiCore/ServerManager>
+#include <QDir>
+#include <QHash>
+#include <QStandardPaths>
 
 using namespace Akonadi::Search::PIM;
 
@@ -126,10 +126,8 @@ qlonglong IndexedItemsPrivate::indexedItemsInDatabase(const std::string &term, c
 qlonglong IndexedItemsPrivate::indexedItems(const qlonglong id)
 {
     const std::string term = QStringLiteral("C%1").arg(id).toStdString();
-    return indexedItemsInDatabase(term, emailIndexingPath())
-           + indexedItemsInDatabase(term, contactIndexingPath())
-           + indexedItemsInDatabase(term, akonotesIndexingPath())
-           + indexedItemsInDatabase(term, calendarIndexingPath());
+    return indexedItemsInDatabase(term, emailIndexingPath()) + indexedItemsInDatabase(term, contactIndexingPath())
+        + indexedItemsInDatabase(term, akonotesIndexingPath()) + indexedItemsInDatabase(term, calendarIndexingPath());
 }
 
 void IndexedItemsPrivate::findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId, const QString &dbPath)
